﻿using System;
using System.Web;
using System.Data;
using System.Collections.Generic;

using CMS.Ecommerce;
using CMS.SettingsProvider;
using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.EventManager;

using Custom.CustomEventManager;

/// <summary>
/// Sample order info provider. 
/// Can be registered either by replacing the OrderInfoProvider.ProviderObject (uncomment the line in SampleECommerceModule.cs) or through cms.extensibility section of the web.config
/// </summary>
public class CustomOrderInfoProvider : OrderInfoProvider
{
    #region "Example: Events as products"

    /// <summary>
    /// Sets (updates or inserts) specified order.
    /// </summary>
    /// <param name="orderObj">Order to be set</param>  
    protected override void SetOrderInfoInternal(OrderInfo orderObj)
    {
        // Add or update the order
        base.SetOrderInfoInternal(orderObj);

        // Remember whether the order is paid
        bool isPaid = ((orderObj != null) && (orderObj.OrderIsPaid));
      
        if (isPaid)
        {
            // Get all attendees that are connected with the current order
            DataSet ds = CustomEventHelper.GetAttendees(orderObj.OrderID);
            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                foreach (DataRow dr in ds.Tables[0].Rows)
                {
                    // Update attendee payment status
                    EventAttendeeInfo attendee = new EventAttendeeInfo(dr);
                    attendee.SetValue(CustomEventHelper.COLUMN_ATTENDEE_PAYMENTCOMPLETED, true);
                    EventAttendeeInfoProvider.SetEventAttendeeInfo(attendee);
                }
            }
        }
    }


    /// <summary>
    /// Deletes specified order.
    /// </summary>
    /// <param name="order">Order object.</param>
    protected override void  DeleteOrderInfoInternal(OrderInfo orderObj)
    {        
        if (orderObj != null)
        {            
            // Delete all attendees that are connected with the given order
            CustomEventHelper.DeleteAttendees(orderObj.OrderID);

            // Delete the order
            base.DeleteOrderInfoInternal(orderObj);
        }
    }

    #endregion
}